==> nuprocess-1.0.1-sources.jar: com/zaxxer/nuprocess/NuAbstractProcessHandler.java <==
/*
 * Copyright (C) 2013 Brett Wooldridge
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zaxxer.nuprocess;

import java.nio.ByteBuffer;

/**
 * Convenience base class for a {@link NuProcessHandler} with default methods that can be
 * overridden.
 * 
 * @author Brett Wooldridge
 */
public abstract class NuAbstractProcessHandler implements NuProcessHandler
{
   /** {@inheritDoc} */
   @Override
   public void onPreStart(NuProcess nuProcess) {
   }

   /** {@inheritDoc} */
   @Override
   public void onStart(NuProcess nuProcess)
   {
   }

   /** {@inheritDoc} */
   @Override
   public void onExit(int statusCode)
   {
   }

   /** {@inheritDoc} */
   @Override
   public void onStdout(ByteBuffer buffer, boolean closed)
   {
      // Ensure we consume the entire buffer in case it's not used.
      buffer.position(buffer.limit());
   }

   /** {@inheritDoc} */
   @Override
   public void onStderr(ByteBuffer buffer, boolean closed)
   {
      // Ensure we consume the entire buffer in case it's not used.
      buffer.position(buffer.limit());
   }

   /** {@inheritDoc} */
   @Override
   public boolean onStdinReady(ByteBuffer buffer)
   {
      return false;
   }
}

==> nuprocess-2.0.6-sources.jar: com/zaxxer/nuprocess/NuAbstractProcessHandler.java <==
/*
 * Copyright (C) 2013 Brett Wooldridge
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zaxxer.nuprocess;

import java.nio.ByteBuffer;

/**
 * Convenience base class for a {@link NuProcessHandler} with default methods
 * that can be overridden.
 * 
 * @author Brett Wooldridge
 */
public abstract class NuAbstractProcessHandler implements NuProcessHandler
{
   /** {@inheritDoc} */
   @Override
   public void onPreStart(NuProcess nuProcess)
   {
   }

   /** {@inheritDoc} */
   @Override
   public void onStart(NuProcess nuProcess)
   {
   }

   /** {@inheritDoc} */
   @Override
   public void onExit(int statusCode)
   {
   }

   /** {@inheritDoc} */
   @Override
   public void onStdout(ByteBuffer buffer, boolean closed)
   {
      // Ensure we consume the entire buffer in case it's not used.
      buffer.position(buffer.limit());
   }

   /** {@inheritDoc} */
   @Override
   public void onStderr(ByteBuffer buffer, boolean closed)
   {
      // Ensure we consume the entire buffer in case it's not used.
      buffer.position(buffer.limit());
   }

   /** {@inheritDoc} */
   @Override
   public boolean onStdinReady(ByteBuffer buffer)
   {
      return false;
   }
}
